==> wicket-devutils-1.4-rc4-sources.jar: org/apache/wicket/devutils/debugbar/InspectorDebugPanel.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.devutils.debugbar;

import org.apache.wicket.Component;
import org.apache.wicket.Page;
import org.apache.wicket.ResourceReference;
import org.apache.wicket.devutils.inspector.InspectorPage;
import org.apache.wicket.model.IModel;
import org.apache.wicket.model.Model;

/**
 * A panel that adds a link to the inspector to the debug bar.
 * 
 * @author Jeremy Thomerson <jthomerson@apache.org>
 */
public class InspectorDebugPanel extends StandardDebugPanel {
	private static final long serialVersionUID = 1L;

	public static final IDebugBarContributor DEBUG_BAR_CONTRIB = new IDebugBarContributor() {
		private static final long serialVersionUID = 1L;

		public Component createComponent(String id, DebugBar debugBar) {
			return new InspectorDebugPanel(id);
		}

	};

	public InspectorDebugPanel(String id) {
		super(id);
	}

	@Override
	protected Class<? extends Page> getLinkPageClass() {
		return InspectorPage.class;
	}

	@Override
	protected ResourceReference getImageResourceReference() {
		return new ResourceReference(InspectorPage.class, "bug.png");
	}

	@Override
	protected IModel<String> getDataModel() {
		return new Model<String>("Inspector");
	}

}

==> wicket-devutils-1.4.20-sources.jar: org/apache/wicket/devutils/debugbar/InspectorDebugPanel.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.devutils.debugbar;

import org.apache.wicket.Component;
import org.apache.wicket.Page;
import org.apache.wicket.PageParameters;
import org.apache.wicket.ResourceReference;
import org.apache.wicket.devutils.inspector.InspectorPage;
import org.apache.wicket.model.IModel;
import org.apache.wicket.model.Model;

/**
 * A panel that adds a link to the inspector to the debug bar.
 * 
 * @author Jeremy Thomerson <jthomerson@apache.org>
 */
public class InspectorDebugPanel extends StandardDebugPanel {
	private static final long serialVersionUID = 1L;

	public static final IDebugBarContributor DEBUG_BAR_CONTRIB = new IDebugBarContributor() {
		private static final long serialVersionUID = 1L;

		public Component createComponent(String id, DebugBar debugBar) {
			return new InspectorDebugPanel(id);
		}

	};

	public InspectorDebugPanel(String id) {
		super(id);
	}

	@Override
	protected Class<? extends Page> getLinkPageClass() {
		return InspectorPage.class;
	}

	@Override
	protected ResourceReference getImageResourceReference() {
		return new ResourceReference(InspectorPage.class, "bug.png");
	}

	@Override
	protected IModel<String> getDataModel() {
		return new Model<String>("Inspector");
	}

	@Override
	protected PageParameters getLinkPageParameters() {
		PageParameters params = new PageParameters();
		params.put("pageMap", getPage().getPageMap().getName());
		params.put("pageId", getPage().getId());
		params.put("version", getPage().getVersions()-1);
		return params;
	}

}
